/*
    Klat4 - A LaTeX editor for KDE4

    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)    
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "klateditcommanddlgimpl.h"

#include <KMessageBox>

#define NOSHORTCUTTEXT						"[none]"

KlatEditCommandDlgImpl::KlatEditCommandDlgImpl(QWidget *parent) : QDialog(parent)
{

	if (objectName().isEmpty())
	    setObjectName("KlatEditCommandDlg");
	resize(471, 475);
	QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
	sizePolicy.setHeightForWidth(sizePolicy.hasHeightForWidth());
	setSizePolicy(sizePolicy);

	KlatEditCommandDlgLayout = new QGridLayout(this);
	KlatEditCommandDlgLayout->setObjectName("KlatEditCommandDlgLayout");
	KlatEditCommandDlgLayout->setSizeConstraint(QLayout::SetMinAndMaxSize);
	KlatEditCommandDlgLayout->setHorizontalSpacing(2);
//	KlatEditCommandDlgLayout->setVerticalSpacing(3);
	KlatEditCommandDlgLayout->setVerticalSpacing(2);
	KlatEditCommandDlgLayout->setContentsMargins(5, 5, 5, 5);

	leftLayout = new QVBoxLayout(this);
	leftLayout->setObjectName("leftLayout");

	sectionLabel = new QLabel(this);
	sectionLabel->setObjectName("sectionLabel");
	leftLayout->addWidget(sectionLabel);

	nameLabel = new QLabel(this);
	nameLabel->setObjectName("nameLabel");
	leftLayout->addWidget(nameLabel);

	cmdLabel = new QLabel(this);
	cmdLabel->setObjectName("cmdLabel");
	leftLayout->addWidget(cmdLabel);

	cmdLineLabel = new QLabel(this);
	cmdLineLabel->setObjectName("cmdLineLabel");
	leftLayout->addWidget(cmdLineLabel);
	KlatEditCommandDlgLayout->addLayout(leftLayout,0,0,1,1);

	rightLayout = new QVBoxLayout(this);
	rightLayout->setObjectName("rightLayout");

	comboBox = new QComboBox(this);
	comboBox->setObjectName("sectionComboBox");
	rightLayout->addWidget(comboBox);

	nameLineEdit = new QLineEdit(this);
	nameLineEdit->setObjectName("nameLineEdit");
	rightLayout->addWidget(nameLineEdit);

	cmdLineEdit = new QLineEdit(this);
	cmdLineEdit->setObjectName("cmdLineEdit");
	rightLayout->addWidget(cmdLineEdit);

	cmdLineLineEdit = new QLineEdit(this);
	cmdLineLineEdit->setObjectName("cmdLineLineEdit");
	rightLayout->addWidget(cmdLineLineEdit);

	KlatEditCommandDlgLayout->addLayout(rightLayout,0,1,1,1);

//	shortcutLayout = new QHBoxLayout(this);
//	shortcutLayout->setObjectName("shortcutLayout");

//	cutButton = new QPushButton(this);
//	cutButton->setObjectName("cutButton");
//	shortcutLayout->addWidget(cutButton);

//	shortcutLabel = new QLabel(this);
//	shortcutLabel->setObjectName("shortcutLabel");
//	shortcutLayout->addWidget(shortcutLabel);

//	horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
//	shortcutLayout->addSpacerItem(horizontalSpacer);

//	cutClearButton = new QPushButton(this);
//	cutClearButton->setObjectName("cutClearButton");
//	shortcutLayout->addWidget(cutClearButton);
//	KlatEditCommandDlgLayout->addLayout(shortcutLayout,1,0,1,2);

	buttonsLayout = new QHBoxLayout(this);
	buttonsLayout->setObjectName("buttonsLayout");

	okButton = new QPushButton(this);
	okButton->setObjectName("okButton");
	buttonsLayout->addWidget(okButton);

	horizontalSpacer2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
	buttonsLayout->addSpacerItem(horizontalSpacer2);

	cancelButton = new QPushButton(this);
	cancelButton->setObjectName("cancelButton");
	buttonsLayout->addWidget(cancelButton);
//	KlatEditCommandDlgLayout->addLayout(buttonsLayout,2,0,1,2);
	KlatEditCommandDlgLayout->addLayout(buttonsLayout,1,0,1,2);

	setWindowTitle(tr("Edit execution command", 0));
	sectionLabel->setText(tr("Section", 0));
	nameLabel->setText(tr("Menu Name", 0));
	cmdLabel->setText(tr("Command", 0));
	cmdLineLabel->setText(tr("Parameters", 0));
//	cutButton->setText(tr("Change"));
//	cutClearButton->setText(tr("Clear", 0));
	okButton->setText(tr("Ok", 0));
	cancelButton->setText(tr("Cancel", 0));

	connect(okButton,SIGNAL(clicked()),this,SLOT(slotOkButtonPressed()));
	connect(cancelButton,SIGNAL(clicked()),this,SLOT(reject()));
//	connect(cutButton,SIGNAL(capturedShortcut(const KShortcut &)),this,SLOT(slotChangeShortcut(const KShortcut &)));
//	connect(cutButton,SIGNAL(clicked()),this,SLOT(slotChangeShortcut()));
//	connect(cutClearButton,SIGNAL(clicked()),this,SLOT(slotClearShortcut()));
}

KlatEditCommandDlgImpl::~KlatEditCommandDlgImpl()
{
}

int KlatEditCommandDlgImpl::exec()
{
	comboBox->addItem("compile");
	comboBox->addItem("convert");
	comboBox->addItem("view");
	nameLineEdit->setText(mname);
	cmdLineEdit->setText(cmd);
	cmdLineLineEdit->setText(cmdLine);
//	QList<QKeySequence> seq=(QList<QKeySequence>)cut;
//	QKeySequence kseq=seq.value(0);
//	if (kseq.count() > 0)
//		shortcutLabel->setText(kseq.toString());
//	else
//		shortcutLabel->setText(NOSHORTCUTTEXT);
	return QDialog::exec();
}

void KlatEditCommandDlgImpl::slotOkButtonPressed()
{
	sect = comboBox->currentText();
	mname = nameLineEdit->text();
	cmd = cmdLineEdit->text();
	cmdLine = cmdLineLineEdit->text();
	// the shortcut has already been saved

	bool valid;
	
	if (mname.length() == 0)
		valid = false;
	else
	{
		int i,len;
		bool found;
		
		len = mname.length();
		for (i = 0,found = false ; !found && i < len ; i++)
		{
			if (!(mname[i] == ' ' || mname[i] == '\t'))
				found = true;
		}

		if (found)
			valid = true;
		else
			valid = false;
	}
	
	if (!valid)
	{
		KMessageBox::messageBox(this,KMessageBox::Information,"You must specify a name to appear in the menu","No menu name");
		return;
	}
	accept();
}


void KlatEditCommandDlgImpl::slotChangeShortcut(const KShortcut &newshortcut)
{
//	cut = newshortcut;
//	shortcutLabel->setText(cut.toString());
}

void KlatEditCommandDlgImpl::slotClearShortcut()
{
//	QList<QKeySequence> seq = (QList<QKeySequence>)cut;
//	QList<QKeySequence>::iterator it;
//	for(it=seq.begin();it!=seq.end();it++)
//	      cut.remove((*it));
//	shortcutLabel->setText(NOSHORTCUTTEXT);
}

