/*
    Klat4 - A LaTeX editor for KDE4

    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef KLATEDITTAB_H

#define KLATEDITTAB_H

#include <KTabWidget>

class KUrl;
class KlatOutputTab;
class KlatToolTab;
class KlatEditWidget;
class KProcess;
class KListView;
class QDropEvent;
class QDragEnterEvent;
class QFocusEvent;
namespace KTextEditor {class View;}

class KlatEditTab : public KTabWidget
{
	Q_OBJECT
public:
	KlatEditTab(QWidget *parent = 0);
	~KlatEditTab();
	void setOutputWidget(KlatOutputTab *w)					{ outputtab = w; }
	void setToolWidget(KlatToolTab *w)					{ tooltab = w; }
	void executeCommand(const QString &cmdline, const QString &filename,bool savefirst);
	bool areAllDocumentsSaved();
signals:
	void signalCursorPositionChanged(int line,int col);
	void signalFileOpened(const KUrl &url);
	void signalNewDocument (KTextEditor::View*);
	void signalOutputRead(QByteArray);
	void signalErrorRead(QByteArray);
public slots:
	void slotFileNew();
	void slotFileOpen();
	void slotFileClose();
	void slotInsertString(const QString &str,int advance);
	void slotOpenUrl(const KUrl &url);
	void slotDocNameChanged(KlatEditWidget *,const QString);
	void slotNextDocument();
	void slotPrevDocument();
private slots:
	void slotProcessExited();
	void slotProcessError();
	void slotReadStandardOutput();
	void slotReadStandardError();
	void slotNewCursorPos();
	void slotPageChanged();
private:
	void saveAsProcedure(KlatEditWidget *w);
	bool getFilenameAndPath(const KUrl &url,QString *fname,QString *path = 0);
	QString getBaseName(const QString &fname);
	void dropEvent(QDropEvent *e);
	void dragEnterEvent(QDragEnterEvent *e);
	void setFocus();

	KlatOutputTab *outputtab;
	KlatToolTab *tooltab;
	KProcess *process;
	int counter;
};

#endif // KLATEDITTAB_H
