/*
    Klat4 - A LaTeX editor for KDE4
    
    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "klateditwidget.h"
#include "klateditwidgetmanager.h"
#include "klattooltab.h"

#include <QDropEvent>

KlatEditWidget::KlatEditWidget(QWidget *parent) : QFrame(parent)
{
	KlatEditWidgetManager *mgr;
	
	mgr = KlatEditWidgetManager::instance();
	doc = mgr->createDocument();

	view = qobject_cast<KTextEditor::View *>(doc->createView(this));
	QMenu *tmpMenu = view->defaultContextMenu();
	view->setContextMenu(tmpMenu);

	slotModeChanged();
	slotHighlightingModeChanged();

	QObject::connect(view,SIGNAL(cursorPositionChanged(KTextEditor::View*,const KTextEditor::Cursor&)),this,SLOT(slotCursorPositionChanged()));
	QObject::connect(doc,SIGNAL(modeChanged(KTextEditor::Document*)),this,SLOT(slotModeChanged()));
	QObject::connect(doc,SIGNAL(highlightingModeChanged(KTextEditor::Document*)),this,SLOT(slotHighlightingModeChanged()));
	QObject::connect(doc,SIGNAL(documentNameChanged(KTextEditor::Document *)),this,SLOT(slotDocNameChanged()));
}


KlatEditWidget::~KlatEditWidget()
{
	KlatEditWidgetManager *mgr;

	mgr = KlatEditWidgetManager::instance();
	delete view;
	mgr->destroyDocument(doc);
}

int KlatEditWidget::cursorLine()
{
	return view->cursorPositionVirtual().line();
}

int KlatEditWidget::cursorColumn()
{
	return view->cursorPositionVirtual().column();
}

int KlatEditWidget::cursorColumnReal()
{
	return view->cursorPosition().column();
}

void KlatEditWidget::insertText(int row,int col,const QString &str)
{
	KTextEditor::Cursor pos(row,col); doc->insertText(pos,str);
}

void KlatEditWidget::setCursorPositionReal(int row,int col)
{
	KTextEditor::Cursor pos(row,col); view->setCursorPosition(pos);
}

void KlatEditWidget::slotCursorPositionChanged()
{
	emit cursorPositionChanged();
}

bool KlatEditWidget::save()
{
	if(doc->documentSave()) 
		return true;
	else
		return false;
}

bool KlatEditWidget::openUrl(const KUrl &url)
{
	if (doc->openUrl(url))
	{
		return true;
	}
	return false;
}

void KlatEditWidget::configDialog()
{
	KlatEditWidgetManager *mgr;
	KTextEditor::Document *doc;
	KTextEditor::View *view;

	mgr = KlatEditWidgetManager::instance();
	doc = mgr->createDocument();
	view = (KTextEditor::View *)doc->createView(0);
	doc->editor()->configDialog(0);
	mgr->destroyDocument(doc);
}

void KlatEditWidget::resizeEvent(QResizeEvent *e)
{
	view->resize(e->size());
}

void KlatEditWidget::slotModeChanged()
{
    if(doc->mode()!="LaTeX")
	doc->setMode(QString("LaTeX"));
}

void KlatEditWidget::slotHighlightingModeChanged()
{
    if(doc->highlightingMode()!="LaTeX")
	doc->setHighlightingMode(QString("LaTeX"));
}

void KlatEditWidget::slotDocNameChanged()
{
	emit documentNameChanged(this,doc->documentName());
}
