/*
    Klat4 - A LaTeX editor for KDE4
    
    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)
    Copyright (C) 2008  Dmitry V. Reshetnikov (genserg@hotmail.com)
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "klatexecsettingsdlgimpl.h"
#include "klateditcommanddlgimpl.h"

#include <KLocalizedString>


KlatExecSettingsDlgImpl::KlatExecSettingsDlgImpl(QWidget *parent) : QDialog(parent) 
{

	if (objectName().isEmpty())
		setObjectName("KlatExecSettingsDlg");
	resize(600, 300);
	QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
	sizePolicy.setHeightForWidth(sizePolicy.hasHeightForWidth());
	setSizePolicy(sizePolicy);

	gridLayout = new QGridLayout(this);
	gridLayout->setObjectName("gridLayout");
	gridLayout->setHorizontalSpacing(2);
	gridLayout->setVerticalSpacing(2);
	gridLayout->setContentsMargins(5, 5, 5, 5);

	textLabel1 = new QLabel(0);
	textLabel1->setObjectName("textLabel1");
	gridLayout->addWidget(textLabel1,0,0,1,1);

	leftLayout = new QVBoxLayout(0);
	leftLayout->setObjectName("leftLayout");

	commandView = new QTreeView(0);
	commandView->setObjectName("commandView");
	leftLayout->addWidget(commandView);

	Layout1 = new QHBoxLayout();
	Layout1->setObjectName("Layout1");

	addButton = new QPushButton(0);
	addButton->setObjectName("addButton");
	Layout1->addWidget(addButton);

	editButton = new QPushButton(0);
	editButton->setObjectName("editButton");
	Layout1->addWidget(editButton);

	deleteButton = new QPushButton(0);
	deleteButton->setObjectName("deleteButton");
	Layout1->addWidget(deleteButton);

	horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
	Layout1->addSpacerItem(horizontalSpacer);

	leftLayout->addLayout(Layout1);

	gridLayout->addLayout(leftLayout,1,0,1,1);

	rightLayout = new QVBoxLayout();
	rightLayout->setObjectName("Layout2");

	upButton = new QPushButton(0);
	upButton->setObjectName("upButton");
	rightLayout->addWidget(upButton);

	downButton = new QPushButton(0);
	downButton->setObjectName("downButton");
	rightLayout->addWidget(downButton);

	verticalSpacer2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Minimum);
	rightLayout->addSpacerItem(verticalSpacer2);

	okButton = new QPushButton(0);
	okButton->setObjectName("okButton");
	okButton->setDefault(true);
	rightLayout->addWidget(okButton);

	cancelButton = new QPushButton(0);
	cancelButton->setObjectName("cancelButton");
	rightLayout->addWidget(cancelButton);

	verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);
	rightLayout->addSpacerItem(verticalSpacer);

	gridLayout->addLayout(rightLayout, 1, 1, 1, 1);

	setWindowTitle(tr("Execution Settings", 0));
	addButton->setText(tr("Add", 0));
	editButton->setText(tr("Edit", 0));
	deleteButton->setText(tr("Delete", 0));
	textLabel1->setText(tr("Here, you can define the commands in the \"Execute\" menu.\n" "The '%' symbol represents the base name of the file you are \n" "editing (the file name without extension).", 0));
	okButton->setText(tr("Ok", 0));
	cancelButton->setText(tr("Cancel", 0));
	downButton->setText(tr("Down", 0));
	upButton->setText(tr("Up", 0));

	QObject::connect(addButton,SIGNAL(clicked()),this,SLOT(slotAdd()));
	QObject::connect(editButton,SIGNAL(clicked()),this,SLOT(slotEdit()));
	QObject::connect(deleteButton,SIGNAL(clicked()),this,SLOT(slotDelete()));
	QObject::connect(okButton,SIGNAL(clicked()),this,SLOT(accept()));
	QObject::connect(upButton,SIGNAL(clicked()),this,SLOT(slotUp()));
	QObject::connect(downButton,SIGNAL(clicked()),this,SLOT(slotDown()));
	QObject::connect(cancelButton,SIGNAL(clicked()),this,SLOT(reject()));

	cfgModel = new KlatExecConfigModel(this);
	QObject::connect(this,SIGNAL(signalDataChanged(const QModelIndex &,const QModelIndex &)),cfgModel,SLOT(slotDataChanged(const QModelIndex &,const QModelIndex &)));
	QObject::connect(this,SIGNAL(signalRemoveRow(int)),cfgModel,SLOT(slotDeleteRow(int)));
	QObject::connect(this,SIGNAL(signalInsertRow(const QModelIndex &)),cfgModel,SLOT(slotInsertRow(const QModelIndex &)));
	QObject::connect(this,SIGNAL(signalEditRow(const QModelIndex &)),cfgModel,SLOT(slotEditRow(const QModelIndex &)));
	commandView->setModel(cfgModel);
	commandView->setSortingEnabled(false);
	commandView->setSelectionMode(QAbstractItemView::SingleSelection);
}

KlatExecSettingsDlgImpl::~KlatExecSettingsDlgImpl()
{
}

int KlatExecSettingsDlgImpl::exec()
{
	commandView->setCurrentIndex(cfgModel->index(0));
	QModelIndex idx = commandView->currentIndex();
	if(idx.isValid())
		commandView->update(idx);
	return QDialog::exec();
}

void KlatExecSettingsDlgImpl::slotAdd()
{
	QModelIndex index = commandView->currentIndex();

	if(!index.isValid())
		return;

	emit signalInsertRow(index);
}

void KlatExecSettingsDlgImpl::slotEdit()
{
	QModelIndex index = commandView->currentIndex();

	if(!index.isValid())
		return;
	
	emit signalEditRow(index);
}

void KlatExecSettingsDlgImpl::slotDelete()
{
	KlatExecConfig cfg=getExecConfig();
	QModelIndex index = commandView->currentIndex();

	if(!index.isValid())
		return;

	emit signalRemoveRow(index.row());
}

void KlatExecSettingsDlgImpl::slotUp()
{
	KlatExecConfig cfg=getExecConfig();
	QModelIndex index = commandView->currentIndex();

	if(!index.isValid())
		return;

	if(cfg.gotoEntry(index.row()-1))
	{
		QString strSection = cfg.section();
		cfg.gotoEntry(index.row());
		if(cfg.section() == strSection)
		{
			KlatExecMenuEntry e = cfg.entry();
			cfg.deleteCurrent();
			cfg.gotoEntry(index.row()-2);
			cfg.insertAfterCurrent(e);
			setExecConfig(cfg);
			emit signalDataChanged(index,cfgModel->index(index.row()+1));
			commandView->setCurrentIndex(cfgModel->index(index.row()-1));
		}
	}
}

void KlatExecSettingsDlgImpl::slotDown()
{
	KlatExecConfig cfg=getExecConfig();
	QModelIndex index = commandView->currentIndex();

	if(!index.isValid())
		return;

	if(cfg.gotoEntry(index.row()+1))
	{
		QString strSection = cfg.section();
		cfg.gotoEntry(index.row());
		if(cfg.section() == strSection)
		{
			KlatExecMenuEntry e = cfg.entry();
			cfg.deleteCurrent();
			cfg.gotoEntry(index.row());
			cfg.insertAfterCurrent(e);
			setExecConfig(cfg);
			emit signalDataChanged(index,cfgModel->index(index.row()+1));
			commandView->setCurrentIndex(cfgModel->index(index.row()+1));
		}
	}
}

KlatExecConfigModel::KlatExecConfigModel(QObject * parent) : QAbstractListModel(parent)
{
}

KlatExecConfigModel::~KlatExecConfigModel()
{
}

int KlatExecConfigModel::rowCount(const QModelIndex &parent) const
{
	int i=0;
	KlatExecConfig tmp=execConfig;
	if(tmp.gotoFirstEntry())
		do
			i++;
		while(tmp.gotoNextEntry());
	return i;
}

int KlatExecConfigModel::columnCount(const QModelIndex &parent) const
{
//	return (int)5;
	return (int)4;
}

QVariant KlatExecConfigModel::data(const QModelIndex &index, int role) const
{
	KlatExecConfig tmp = execConfig;
	if (!index.isValid())
		return QVariant();
	if (index.row() >= rowCount())
		return QVariant();
	if (role == Qt::DisplayRole)
	{
		if(tmp.gotoEntry(index.row()))
		{
			if(index.column() == 0)
				return tmp.entry().menuName();
			else if (index.column() == 1)
				return tmp.entry().section();
			else if (index.column() == 2)
				return tmp.entry().command();
			else if (index.column() == 3)
				return tmp.entry().commandLine();
//			else if (index.column() == 4)
//				return tmp.entry().shortcut().toString();
		} 
		else
			return QVariant();
	}
	else
		return QVariant();
}

QVariant KlatExecConfigModel::headerData(int sect, Qt::Orientation orientation, int role) const
{
	if (role != Qt::DisplayRole)
		return QVariant();

	if(sect == 0)
		return QString(i18n("Menu name"));
	else if(sect == 1)
		return QString(i18n("Command type"));
	else if(sect == 2)
		return QString(i18n("Command"));
	else if(sect == 3)
		return QString(i18n("Parameters"));
//	else if(sect == 4)
//		return QString("Shortcut");
}

void KlatExecConfigModel::slotDataChanged(const QModelIndex &top, const QModelIndex &bottom)
{
	emit dataChanged(top,bottom);
}

void KlatExecConfigModel::slotDeleteRow(int index)
{
	if(index>=rowCount())
		return;
	if(index==0)
		return;
	if(execConfig.gotoEntry(index))
	{
		beginRemoveRows(QModelIndex(), index, index);
		execConfig.deleteCurrent();
		endRemoveRows();
	}
	removeRows(index,1);
}

void KlatExecConfigModel::slotInsertRow(const QModelIndex &idx)
{
	KlatEditCommandDlgImpl dlg(0);
	if (dlg.exec() != QDialog::Accepted)
		return;

	if(!idx.isValid())
		return;

	if(execConfig.gotoEntry(idx.row()))
	{
		if(execConfig.section() == dlg.section())
		{
			beginInsertRows(QModelIndex(),idx.row(),idx.row());
			execConfig.insertAfterCurrent(KlatExecMenuEntry(dlg.section(),dlg.menuName(),dlg.command(),dlg.commandLine(),dlg.shortcut()));
			endInsertRows();
		}
		else if(execConfig.gotoSectionEndEntry(dlg.section()))
		{
			int pos=execConfig.position();
			beginInsertRows(QModelIndex(),pos,pos);
			execConfig.insertAfterCurrent(KlatExecMenuEntry(dlg.section(),dlg.menuName(),dlg.command(),dlg.commandLine(),dlg.shortcut()));
			endInsertRows();
		}
	}
}

void KlatExecConfigModel::slotEditRow(const QModelIndex &idx)
{
	if(execConfig.gotoEntry(idx.row()))
	{
		KlatEditCommandDlgImpl dlg(0);
		dlg.setMenuName(execConfig.menuName());
		dlg.setCommand(execConfig.command());
		dlg.setCommandLine(execConfig.commandLine());
		dlg.setSection(execConfig.section());
		dlg.setShortcut(execConfig.shortcut());

		if (dlg.exec() != QDialog::Accepted)
			return;

		QString menuname,cmd,cmdLine,section;
		KShortcut cut;

		menuname = dlg.menuName();
		cmd = dlg.command();
		cmdLine = dlg.commandLine();
		section = dlg.section();
		cut = dlg.shortcut();
		execConfig.changeCurrent(KlatExecMenuEntry(section,menuname,cmd,cmdLine,cut));
	}
	emit dataChanged(idx,idx);
}
