/*
    Klat4 - A LaTeX editor for KDE4

    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)
    Copyright (C) 2008  Dmitry V. Reshetnikov (genserg@hotmail.com)
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef KLATEXECSETTINGSDLGIMPL_H

#define KLATEXECSETTINGSDLGIMPL_H

#include "klatexecconfig.h"

#include <QtGui/QDialog>
#include <QAbstractListModel>
#include <QtGui/QGridLayout>
#include <QtGui/QHBoxLayout>
#include <QtGui/QLabel>
#include <QtGui/QPushButton>
#include <QtGui/QSpacerItem>
#include <QtGui/QTreeView>

class KlatExecConfigModel : public QAbstractListModel
{
	Q_OBJECT
public:
	KlatExecConfigModel(QObject * parent=0);
	~KlatExecConfigModel();
	int rowCount(const QModelIndex &parent = QModelIndex()) const;
	int columnCount(const QModelIndex &parent = QModelIndex()) const;
	QVariant data(const QModelIndex &index, int role) const;
	QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

	void setExecConfig(const KlatExecConfig &conf)				{ execConfig = conf; }
	KlatExecConfig getExecConfig()						{ return execConfig; }

private slots:
	void slotDataChanged(const QModelIndex &top, const QModelIndex &bottom);
	void slotDeleteRow(int index);
	void slotInsertRow(const QModelIndex &index);
	void slotEditRow(const QModelIndex &index);
private:
	KlatExecConfig execConfig;
};

class KlatExecSettingsDlgImpl : public QDialog
{
	Q_OBJECT
public:
	KlatExecSettingsDlgImpl(QWidget* parent = 0);
	~KlatExecSettingsDlgImpl();
	
	void setExecConfig(const KlatExecConfig &conf)				{ cfgModel->setExecConfig(conf); }
	KlatExecConfig getExecConfig()						{ return cfgModel->getExecConfig(); }
	int exec();
signals:
	void signalDataChanged(const QModelIndex &top, const QModelIndex &bottom);
	void signalRemoveRow(int index);
	void signalInsertRow(const QModelIndex &index);
	void signalEditRow(const QModelIndex &index);

private slots:
	void slotAdd();
	void slotEdit();
	void slotDelete();
	void slotUp();
	void slotDown();
private:
	QGridLayout *gridLayout;
	QHBoxLayout *Layout1;
	QVBoxLayout *leftLayout;
	QVBoxLayout *rightLayout;
	QPushButton *addButton;
	QPushButton *editButton;
	QPushButton *deleteButton;
	QLabel *textLabel1;
	QSpacerItem *horizontalSpacer;
	QPushButton *okButton;
	QPushButton *cancelButton;
	QSpacerItem *verticalSpacer;
	QSpacerItem *verticalSpacer2;
	QPushButton *downButton;
	QPushButton *upButton;
	QTreeView *commandView;

	KlatExecConfigModel * cfgModel;
};

#endif // KLATEXECSETTINGSDLGIMPL_H
