/*
    Klat4 - A LaTeX editor for KDE4

    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)    
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "klatoutputtab.h"

#include <KTextEdit>
#include <KLocalizedString>
#include <QTextCodec>

KlatOutputTab::KlatOutputTab(QWidget *parent) : KTabWidget(parent)
{
	out = new KTextEdit(this);
	err = new KTextEdit(this);
	out->setReadOnly(true);
	err->setReadOnly(true);
	addTab(out,i18n("Stdout"));
	addTab(err,i18n("Stderr"));
}

KlatOutputTab::~KlatOutputTab()
{
}

void KlatOutputTab::newProcess(const QString &cmd)
{
	out->clear();
	err->clear();

	QString cmdinfo = i18n("Executing the following command line:\n");
	
	cmdinfo += cmd;
	cmdinfo += "\n\n";
	addTextToEditWidget(out,cmdinfo);
	addTextToEditWidget(err,cmdinfo);
}

void KlatOutputTab::slotAddStdout(QByteArray strOut)
{
	QTextCodec *codec = QTextCodec::codecForName("Windows-1251");
	QString str = codec->toUnicode(strOut); 
	addTextToEditWidget(out,str);
}

void KlatOutputTab::slotAddStderr(QByteArray strErr)
{
	QTextCodec *codec = QTextCodec::codecForName("Windows-1251");
	QString str = codec->toUnicode(strErr); 
	addTextToEditWidget(err,str);
}

void KlatOutputTab::addTextToEditWidget(KTextEdit *w,const QString str)
{
	w->append(str);
}

void KlatOutputTab::finishedProcess()
{
	QString info = i18n("\nProcess finished\n");
	addTextToEditWidget(out,info);
	addTextToEditWidget(err,info);
}
